@@ -10,7 +10,7 @@ use Dumpvalue;
 use version ();
 use File::Spec ();
 
-our $VERSION = '0.35';
+our $VERSION = '0.37';
 our $VERBOSE = 0;
 our $ALLOW_DEV_VERSION = 0;
 our $FORK = 0;
@@ -144,12 +144,25 @@ sub parse {
                 next;            # don't screw up 02packages
             }
         }
+        unless ($self->_version_ok($pp)) {
+            $errors{$package} = {
+                long_version => qq{Version string exceeds maximum allowed length of 16b: "$pp->{version}"},
+                infile => $pp->{infile},
+            };
+            next;
+        }
         $checked_in{$package} = $ppp->{$package};
     }                       # end foreach package
 
     return (wantarray && %errors) ? (\%checked_in, \%errors) : \%checked_in;
 }
 
+sub _version_ok {
+    my ($self, $pp) = @_;
+    return if length($pp->{version} || 0) > 16;
+    return 1
+}
+
 sub _perm_check {
     my ($self, $package) = @_;
     my $userid = $self->{USERID};
@@ -336,7 +349,6 @@ sub _packages_per_pmfile {
     my $filemtime = $self->{MTIME};
     my $version = $self->{VERSION};
 
-    $DB::single++;
     open my $fh, "<", "$pmfile" or return $ppp;
 
     local $/ = "\n";
